@@ -188,6 +188,16 @@ static void cc_clear(curve_ptr c)
     free(c->data);
 }
 
+void cc_frobenius(point_ptr r, point_ptr p, mpz_ptr q)
+{
+    if (point_is_inf(p)) {
+	point_set_inf(r);
+	return;
+    }
+    element_pow(r->x, p->x, q);
+    element_pow(r->y, p->y, q);
+}
+
 void curve_init_cc_j(curve_ptr c, element_ptr j)
 //assumes j != 0, 1728
 //TODO: call curve_init_cc_ab instead of duplicating code
