@@ -740,7 +740,7 @@ void field_init_polymod_no_nqr(field_ptr f, element_ptr poly)
 	f->fixed_length_in_bytes = -1;
 	f->length_in_bytes = polymod_length_in_bytes;
     } else {
-	f->fixed_length_in_bytes = poly->field->fixed_length_in_bytes * poly_degree(poly);
+	f->fixed_length_in_bytes = p->field->fixed_length_in_bytes * poly_degree(poly);
     }
     mpz_init(f->order);
     n = pd->coeff->count;
