@@ -8,7 +8,8 @@ int main()
     element_t f, g;
 
     mpz_init(prime);
-    mpz_set_si(prime, 211);
+    mpz_set_ui(prime, 100000);
+    mpz_nextprime(prime, prime);
     field_init_fp(zp, prime);
     field_init_poly(rx, zp);
     element_init(f, rx);
@@ -19,7 +20,7 @@ int main()
     poly_set_coeff(f, a, 2);
     poly_set_coeff(f, a, 0);
 
-    element_out_str(stdout, f);
+    element_out_str(stdout, 0, f);
     if (poly_is_irred(f)) {
 	printf(" is irreducible\n");
     } else {
@@ -34,32 +35,49 @@ int main()
     element_random(f);
     element_random(g);
     printf("f: ");
-    element_out_str(stdout, f);
+    element_out_str(stdout, 0, f);
     printf(", g: ");
-    element_out_str(stdout, g);
+    element_out_str(stdout, 0, g);
     printf("\n");
     element_mul(g, f, g);
     printf("prod: ");
-    element_out_str(stdout, g);
+    element_out_str(stdout, 0, g);
     printf("\n");
     element_invert(f, f);
     printf("inv f: ");
-    element_out_str(stdout, f);
+    element_out_str(stdout, 0, f);
     printf("\n");
     {
 	do {
 	    element_random(f);
 	} while (!element_is_sqr(f));
 	printf("random square f: ");
-	element_out_str(stdout, f);
+	element_out_str(stdout, 0, f);
 	printf("\n");
 	element_sqrt(f, f);
 	printf("sqrt f: ");
-	element_out_str(stdout, f);
+	element_out_str(stdout, 0, f);
 	printf("\n");
 	element_mul(f, f, f);
 	printf("f: ");
-	element_out_str(stdout, f);
+	element_out_str(stdout, 0, f);
+	printf("\n");
+    }
+    {
+	unsigned char *data;
+	int i;
+	int n = element_length_in_bytes(f);
+	printf("serialized f =");
+	data = (unsigned char *) malloc(n);
+	element_to_bytes(data, f);
+	for (i=0; i<n; i++) {
+	    printf(" %d", data[i]);
+	}
+	printf("\n");
+	printf("deserialize check = ");
+	element_random(f);
+	element_from_bytes(f, data);
+	element_out_str(stdout, 10, f);
 	printf("\n");
     }
 
